==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.rest/src/com/openexchange/office/rest/ParameterDefinitions.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.rest;

public class ParameterDefinitions {
    private ParameterDefinitions() { /* nothing to do */ }

    public final static String PARAM_AUTH_CODE          = "cryptoAuth";
    public final static String PARAM_FILE_ID            = "id";
    public final static String PARAM_FOLDER_ID          = "folder_id";
    public final static String PARAM_REMOVE_FILE_ID     = "remove_file_id";
    public final static String PARAM_SUB_ACTION         = "subaction";
    public final static String PARAM_SUBACTION_CLOSE    = "close";
    public final static String PARAM_SUBACTION_OPEN     = "open";
    public final static String PARAM_SUBACTION_PREFETCH = "prefetch";
    public final static String PARAM_TYPE               = "type";
    public final static String PARAM_VERSION            = "version";
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.rest/src/com/openexchange/office/rest/ParameterDefinitions.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.rest;

public class ParameterDefinitions {
    private ParameterDefinitions() { /* nothing to do */ }

    public final static String PARAM_AUTH_CODE          = "cryptoAuth";
    public final static String PARAM_FILE_ID            = "id";
    public final static String PARAM_FOLDER_ID          = "folder_id";
    public final static String PARAM_REMOVE_FILE_ID     = "remove_file_id";
    public final static String PARAM_SUB_ACTION         = "subaction";
    public final static String PARAM_SUBACTION_CLOSE    = "close";
    public final static String PARAM_SUBACTION_OPEN     = "open";
    public final static String PARAM_SUBACTION_PREFETCH = "prefetch";
    public final static String PARAM_TYPE               = "type";
    public final static String PARAM_VERSION            = "version";
    public final static String PARAM_FILENAME           = "filename";
    public final static String PARAM_MIMETYPE           = "mimetype";
    public final static String PARAM_CLIENTUID          = "client_uid";
    public final static String PARAM_DOCUID             = "doc_uid";

}
